@@ -127,7 +127,9 @@ pub enum TransactionError {
     InvalidAddressLookupTableIndex,
 
     /// Transaction leaves an account with a lower balance than rent-exempt minimum
-    #[error("Transaction leaves an account with a lower balance than rent-exempt minimum")]
+    #[error(
+        "Transaction leaves an account with data with a lower balance than rent-exempt minimum"
+    )]
     InvalidRentPayingAccount,
 
     /// Transaction would exceed max Vote Cost Limit
